@@ -31,7 +31,7 @@ NotesAgentSettingsDialog::NotesAgentSettingsDialog(QWidget *parent)
     auto mainLayout = new QVBoxLayout(this);
     setModal(true);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -57,7 +57,7 @@ NotesAgentSettingsDialog::NotesAgentSettingsDialog(QWidget *parent)
                                       QStringLiteral(KNOTES_VERSION),
                                       i18n("Notes Agent."),
                                       KAboutLicense::GPL_V2,
-                                      i18n("Copyright (C) 2013-2020 Laurent Montel"));
+                                      i18n("Copyright (C) 2013-2021 Laurent Montel"));
 
     aboutData.addAuthor(i18n("Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
 
@@ -79,7 +79,7 @@ NotesAgentSettingsDialog::~NotesAgentSettingsDialog()
 static const char myConfigGroupName[] = "NotesAgentSettingsDialog";
 void NotesAgentSettingsDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), myConfigGroupName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), myConfigGroupName);
 
     const QSize size = group.readEntry("Size", QSize(500, 300));
     if (size.isValid()) {
@@ -89,7 +89,7 @@ void NotesAgentSettingsDialog::writeConfig()
 
 void NotesAgentSettingsDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), myConfigGroupName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), myConfigGroupName);
     group.writeEntry("Size", size());
     group.sync();
 }
