@@ -3,14 +3,13 @@
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
-#ifndef NOTESMANAGER_H
-#define NOTESMANAGER_H
+#pragma once
 
 #include <QObject>
 
 #include "notesagentalarmdialog.h"
 
-#include <Item>
+#include <Akonadi/Item>
 #include <QPointer>
 class QTcpServer;
 class QTimer;
@@ -29,7 +28,7 @@ class NotesManager : public QObject
     Q_OBJECT
 public:
     explicit NotesManager(QObject *parent = nullptr);
-    ~NotesManager();
+    ~NotesManager() override;
 
     void stopAll();
     void updateNetworkListener();
@@ -58,4 +57,3 @@ private:
     QPointer<NotesAgentAlarmDialog> mAlarmDialog;
 };
 
-#endif // NOTESMANAGER_H
