@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -25,8 +25,8 @@ void NoteEditorUtilsTest::testAddCheckmark_data()
 {
     QTest::addColumn<QString>("input");
     QTest::addColumn<int>("position");
-    QTest::newRow("standard") <<  QStringLiteral("foo") << 0;
-    QTest::newRow("emptyline") <<  QString() << 0;
+    QTest::newRow("standard") << QStringLiteral("foo") << 0;
+    QTest::newRow("emptyline") << QString() << 0;
 }
 
 void NoteEditorUtilsTest::testAddCheckmark()
@@ -39,7 +39,7 @@ void NoteEditorUtilsTest::testAddCheckmark()
     const QString checkMark = QString::fromRawData(unicode, size);
 
     NoteShared::NoteEditorUtils noteUtils;
-    auto *document = new QTextDocument(this);
+    auto document = new QTextDocument(this);
     document->setPlainText(input);
     QTextCursor textCursor(document);
     if (position < 1) {
@@ -51,7 +51,7 @@ void NoteEditorUtilsTest::testAddCheckmark()
 
     noteUtils.addCheckmark(textCursor);
     QCOMPARE(textCursor.document()->toPlainText(), QString(checkMark + input));
-    //QCOMPARE(textCursor.position(), position + checkMark.size());
+    // QCOMPARE(textCursor.position(), position + checkMark.size());
     delete document;
 }
 
