@@ -23,21 +23,9 @@
 
 using namespace NoteShared;
 
-class NoteShared::NoteAlarmDialogPrivate
-{
-public:
-    NoteAlarmDialogPrivate()
-    {
-    }
-
-    KDateComboBox *m_atDate = nullptr;
-    KTimeComboBox *m_atTime = nullptr;
-    QButtonGroup *m_buttons = nullptr;
-};
 
 NoteAlarmDialog::NoteAlarmDialog(const QString &caption, QWidget *parent)
     : QDialog(parent)
-    , d(new NoteShared::NoteAlarmDialogPrivate)
 {
     setWindowTitle(caption);
     auto mainLayout = new QVBoxLayout(this);
@@ -50,13 +38,13 @@ NoteAlarmDialog::NoteAlarmDialog(const QString &caption, QWidget *parent)
     auto pageVBoxLayout = new QVBoxLayout(page);
     pageVBoxLayout->setContentsMargins(0, 0, 0, 0);
 
-    d->m_buttons = new QButtonGroup(this);
+    m_buttons = new QButtonGroup(this);
     auto group = new QGroupBox(i18n("Scheduled Alarm"), page);
     pageVBoxLayout->addWidget(group);
     auto layout = new QVBoxLayout;
     auto none = new QRadioButton(i18n("&No alarm"));
     layout->addWidget(none);
-    d->m_buttons->addButton(none, 0);
+    m_buttons->addButton(none, 0);
 
     group->setLayout(layout);
 
@@ -65,54 +53,51 @@ NoteAlarmDialog::NoteAlarmDialog(const QString &caption, QWidget *parent)
     atHBoxLayout->setContentsMargins(0, 0, 0, 0);
     auto label_at = new QRadioButton(i18n("Alarm &at:"), at);
     atHBoxLayout->addWidget(label_at);
-    d->m_atDate = new KDateComboBox(at);
-    atHBoxLayout->addWidget(d->m_atDate);
-    d->m_atTime = new KTimeComboBox(at);
-    atHBoxLayout->addWidget(d->m_atTime);
+    m_atDate = new KDateComboBox(at);
+    atHBoxLayout->addWidget(m_atDate);
+    m_atTime = new KTimeComboBox(at);
+    atHBoxLayout->addWidget(m_atTime);
     const QDateTime dateTime = QDateTime::currentDateTime();
-    d->m_atDate->setMinimumDate(dateTime.date());
-    d->m_atTime->setMinimumTime(dateTime.time());
-    atHBoxLayout->setStretchFactor(d->m_atDate, 1);
+    m_atDate->setMinimumDate(dateTime.date());
+    m_atTime->setMinimumTime(dateTime.time());
+    atHBoxLayout->setStretchFactor(m_atDate, 1);
     layout->addWidget(at);
-    d->m_buttons->addButton(label_at, 1);
+    m_buttons->addButton(label_at, 1);
 
-    connect(d->m_buttons, qOverload<QAbstractButton *>(&QButtonGroup::buttonClicked), this, &NoteAlarmDialog::slotButtonChanged);
+    connect(m_buttons, qOverload<QAbstractButton *>(&QButtonGroup::buttonClicked), this, &NoteAlarmDialog::slotButtonChanged);
     connect(okButton, &QPushButton::clicked, this, &NoteAlarmDialog::accept);
-    d->m_buttons->button(0)->setChecked(true);
-    slotButtonChanged(d->m_buttons->checkedButton());
+    m_buttons->button(0)->setChecked(true);
+    slotButtonChanged(m_buttons->checkedButton());
     mainLayout->addWidget(page);
     mainLayout->addWidget(buttonBox);
 }
 
-NoteAlarmDialog::~NoteAlarmDialog()
-{
-    delete d;
-}
+NoteAlarmDialog::~NoteAlarmDialog() = default;
 
 void NoteAlarmDialog::setAlarm(const QDateTime &dateTime)
 {
     if (dateTime.isValid()) {
-        d->m_buttons->button(1)->setChecked(true);
-        d->m_atDate->setDate(dateTime.date());
-        d->m_atTime->setTime(dateTime.time());
+        m_buttons->button(1)->setChecked(true);
+        m_atDate->setDate(dateTime.date());
+        m_atTime->setTime(dateTime.time());
     } else {
-        d->m_buttons->button(0)->setChecked(true);
+        m_buttons->button(0)->setChecked(true);
     }
-    slotButtonChanged(d->m_buttons->checkedButton());
+    slotButtonChanged(m_buttons->checkedButton());
 }
 
 void NoteAlarmDialog::slotButtonChanged(QAbstractButton *button)
 {
     if (button) {
-        const int id = d->m_buttons->id(button);
+        const int id = m_buttons->id(button);
         switch (id) {
         case 0:
-            d->m_atDate->setEnabled(false);
-            d->m_atTime->setEnabled(false);
+            m_atDate->setEnabled(false);
+            m_atTime->setEnabled(false);
             break;
         case 1:
-            d->m_atDate->setEnabled(true);
-            d->m_atTime->setEnabled(true);
+            m_atDate->setEnabled(true);
+            m_atTime->setEnabled(true);
             break;
         }
     }
@@ -120,8 +105,8 @@ void NoteAlarmDialog::slotButtonChanged(QAbstractButton *button)
 
 QDateTime NoteAlarmDialog::alarm() const
 {
-    if (d->m_buttons->checkedId() == 1) {
-        return QDateTime(d->m_atDate->date(), d->m_atTime->time());
+    if (m_buttons->checkedId() == 1) {
+        return QDateTime(m_atDate->date(), m_atTime->time());
     } else {
         return QDateTime();
     }
