@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -59,4 +59,4 @@ void NoteAlarmAttributeTest::shouldHaveType()
     QCOMPARE(attr.type(), QByteArray("NoteAlarmAttribute"));
 }
 
-QTEST_MAIN(NoteAlarmAttributeTest)
+QTEST_GUILESS_MAIN(NoteAlarmAttributeTest)
