@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -24,4 +24,4 @@ void ShowFolderNotesAttributeTest::shouldHaveType()
     QCOMPARE(attr.type(), QByteArray("showfoldernotesattribute"));
 }
 
-QTEST_MAIN(ShowFolderNotesAttributeTest)
+QTEST_GUILESS_MAIN(ShowFolderNotesAttributeTest)
