@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -40,7 +40,7 @@ NoteDisplayAttribute::~NoteDisplayAttribute()
 
 NoteDisplayAttribute *NoteDisplayAttribute::clone() const
 {
-    auto *attr = new NoteDisplayAttribute();
+    auto attr = new NoteDisplayAttribute();
     attr->setBackgroundColor(backgroundColor());
     attr->setForegroundColor(foregroundColor());
     attr->setSize(size());
@@ -248,20 +248,10 @@ bool NoteDisplayAttribute::keepBelow() const
     return mKeepBelow;
 }
 
-bool NoteDisplayAttribute::operator ==(const NoteDisplayAttribute &other) const
+bool NoteDisplayAttribute::operator==(const NoteDisplayAttribute &other) const
 {
-    return (backgroundColor() == other.backgroundColor())
-           && (foregroundColor() == other.foregroundColor())
-           && (size() == other.size())
-           && (rememberDesktop() == other.rememberDesktop())
-           && (tabSize() == other.tabSize())
-           && (font() == other.font())
-           && (titleFont() == other.titleFont())
-           && (desktop() == other.desktop())
-           && (isHidden() == other.isHidden())
-           && (position() == other.position())
-           && (showInTaskbar() == other.showInTaskbar())
-           && (keepAbove() == other.keepAbove())
-           && (keepBelow() == other.keepBelow())
-           && (autoIndent() == other.autoIndent());
+    return (backgroundColor() == other.backgroundColor()) && (foregroundColor() == other.foregroundColor()) && (size() == other.size())
+        && (rememberDesktop() == other.rememberDesktop()) && (tabSize() == other.tabSize()) && (font() == other.font()) && (titleFont() == other.titleFont())
+        && (desktop() == other.desktop()) && (isHidden() == other.isHidden()) && (position() == other.position()) && (showInTaskbar() == other.showInTaskbar())
+        && (keepAbove() == other.keepAbove()) && (keepBelow() == other.keepBelow()) && (autoIndent() == other.autoIndent());
 }
