@@ -6,7 +6,7 @@
 #pragma once
 
 #include "noteshared_export.h"
-#include <AkonadiCore/Attribute>
+#include <Akonadi/Attribute>
 
 #include <QColor>
 #include <QFont>
