@@ -9,7 +9,7 @@
 
 #include "noteshared_export.h"
 
-#include <AkonadiCore/Attribute>
+#include <Akonadi/Attribute>
 
 namespace NoteShared
 {
