@@ -6,7 +6,7 @@
 #pragma once
 
 #include "noteshared_export.h"
-#include <AkonadiCore/attribute.h>
+#include <Akonadi/Attribute>
 
 namespace NoteShared
 {
