@@ -3,8 +3,7 @@
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
-#ifndef NOTEACTIONCONFIG_H
-#define NOTEACTIONCONFIG_H
+#pragma once
 #include "noteshared_export.h"
 #include <KCModule>
 namespace NoteShared
@@ -13,7 +12,7 @@ class NOTESHARED_EXPORT NoteActionConfig : public KCModule
 {
     Q_OBJECT
 public:
-    explicit NoteActionConfig(QWidget *parent);
+    explicit NoteActionConfig(QWidget *parent = nullptr, const QVariantList &args = QVariantList());
     /** Reimplemented from KCModule. */
     void load() override;
     void save() override;
@@ -22,4 +21,3 @@ private:
     void slotHelpLinkClicked(const QString &);
 };
 }
-#endif // NOTEACTIONCONFIG_H
