@@ -6,6 +6,10 @@
 #pragma once
 #include "noteshared_export.h"
 #include <KCModule>
+
+class QCheckBox;
+class QLineEdit;
+class QSpinBox;
 namespace NoteShared
 {
 class NoteNetworkConfigWidgetPrivate;
@@ -20,7 +24,9 @@ public:
     void load();
 
 private:
-    NoteNetworkConfigWidgetPrivate *const d;
+    QCheckBox *mTmpChkB = nullptr;
+    QLineEdit *m_kcfg_SenderID = nullptr;
+    QSpinBox *kcfg_Port = nullptr;
 };
 
 class NOTESHARED_EXPORT NoteNetworkConfig : public KCModule
