@@ -10,12 +10,12 @@
 #include "notesharedglobalconfig.h"
 #include <Akonadi/Notes/NoteUtils>
 
-#include <AkonadiCore/Collection>
-#include <AkonadiCore/CollectionFetchJob>
-#include <AkonadiCore/CollectionModifyJob>
-#include <AkonadiCore/EntityDisplayAttribute>
-#include <AkonadiCore/Item>
-#include <AkonadiCore/ItemCreateJob>
+#include <Akonadi/Collection>
+#include <Akonadi/CollectionFetchJob>
+#include <Akonadi/CollectionModifyJob>
+#include <Akonadi/EntityDisplayAttribute>
+#include <Akonadi/Item>
+#include <Akonadi/ItemCreateJob>
 
 #include <KMime/KMimeMessage>
 
@@ -27,31 +27,14 @@
 
 using namespace NoteShared;
 
-class NoteShared::CreateNewNoteJobPrivate
-{
-public:
-    CreateNewNoteJobPrivate(QWidget *widget)
-        : mWidget(widget)
-    {
-    }
-
-    QString mTitle;
-    QString mText;
-    bool mRichText = false;
-    QWidget *const mWidget;
-};
-
 CreateNewNoteJob::CreateNewNoteJob(QObject *parent, QWidget *widget)
     : QObject(parent)
-    , d(new NoteShared::CreateNewNoteJobPrivate(widget))
+    , mWidget(widget)
 {
     connect(this, &CreateNewNoteJob::selectNewCollection, this, &CreateNewNoteJob::slotSelectNewCollection);
 }
 
-CreateNewNoteJob::~CreateNewNoteJob()
-{
-    delete d;
-}
+CreateNewNoteJob::~CreateNewNoteJob() = default;
 
 void CreateNewNoteJob::slotSelectNewCollection()
 {
@@ -60,13 +43,13 @@ void CreateNewNoteJob::slotSelectNewCollection()
 
 void CreateNewNoteJob::setNote(const QString &name, const QString &text)
 {
-    d->mTitle = name;
-    d->mText = text;
+    mTitle = name;
+    mText = text;
 }
 
 void CreateNewNoteJob::setRichText(bool richText)
 {
-    d->mRichText = richText;
+    mRichText = richText;
 }
 
 void CreateNewNoteJob::start()
@@ -84,7 +67,7 @@ void CreateNewNoteJob::createFetchCollectionJob(bool useSettings)
         NoteShared::NoteSharedGlobalConfig::self()->setDefaultFolder(id);
     }
     if (id == -1) {
-        QPointer<SelectedNotefolderDialog> dlg = new SelectedNotefolderDialog(d->mWidget);
+        QPointer<SelectedNotefolderDialog> dlg = new SelectedNotefolderDialog(mWidget);
         if (dlg->exec()) {
             col = dlg->selectedCollection();
         } else {
@@ -108,8 +91,12 @@ void CreateNewNoteJob::slotFetchCollection(KJob *job)
 {
     if (job->error()) {
         qCDebug(NOTESHARED_LOG) << " Error during fetch: " << job->errorString();
-        if (KMessageBox::Yes
-            == KMessageBox::warningYesNo(nullptr, i18n("An error occurred during fetching. Do you want to select a new default collection?"))) {
+        const int answer = KMessageBox::warningYesNo(nullptr,
+                                                     i18n("An error occurred during fetching. Do you want to select a new default collection?"),
+                                                     QString(),
+                                                     KGuiItem(i18nc("@action:button", "Select New Default")),
+                                                     KGuiItem(i18nc("@action:button", "Ignore"), QStringLiteral("dialog-cancel")));
+        if (answer == KMessageBox::Yes) {
             Q_EMIT selectNewCollection();
         } else {
             deleteLater();
@@ -119,8 +106,12 @@ void CreateNewNoteJob::slotFetchCollection(KJob *job)
     auto fetchCollection = qobject_cast<Akonadi::CollectionFetchJob *>(job);
     if (fetchCollection->collections().isEmpty()) {
         qCDebug(NOTESHARED_LOG) << "No collection fetched";
-        if (KMessageBox::Yes
-            == KMessageBox::warningYesNo(nullptr, i18n("An error occurred during fetching. Do you want to select a new default collection?"))) {
+        const int answer = KMessageBox::warningYesNo(nullptr,
+                                                     i18n("An error occurred during fetching. Do you want to select a new default collection?"),
+                                                     QString(),
+                                                     KGuiItem(i18nc("@action:button", "Select New Default")),
+                                                     KGuiItem(i18nc("@action:button", "Ignore"), QStringLiteral("dialog-cancel")));
+        if (answer == KMessageBox::Yes) {
             Q_EMIT selectNewCollection();
         } else {
             deleteLater();
@@ -130,12 +121,16 @@ void CreateNewNoteJob::slotFetchCollection(KJob *job)
     Akonadi::Collection col = fetchCollection->collections().at(0);
     if (col.isValid()) {
         if (!col.hasAttribute<NoteShared::ShowFolderNotesAttribute>()) {
-            if (KMessageBox::Yes
-                == KMessageBox::warningYesNo(nullptr,
-                                             i18n("Collection is hidden. New note will be stored but not displayed. Do you want to show collection?"))) {
+            const int answer =
+                KMessageBox::warningYesNo(nullptr,
+                                          i18n("Collection is hidden. New note will be stored but not displayed. Do you want to show collection?"),
+                                          QString(),
+                                          KGuiItem(i18nc("@action::button", "Show Collection")),
+                                          KGuiItem(i18nc("@action::button", "Do Not Show", QStringLiteral("dialog-cancel"))));
+            if (answer == KMessageBox::Yes) {
                 col.addAttribute(new NoteShared::ShowFolderNotesAttribute());
-                auto job = new Akonadi::CollectionModifyJob(col);
-                connect(job, &Akonadi::CollectionModifyJob::result, this, &CreateNewNoteJob::slotCollectionModifyFinished);
+                auto modifyJob = new Akonadi::CollectionModifyJob(col);
+                connect(modifyJob, &Akonadi::CollectionModifyJob::result, this, &CreateNewNoteJob::slotCollectionModifyFinished);
             }
         }
         Akonadi::Item newItem;
@@ -144,25 +139,25 @@ void CreateNewNoteJob::slotFetchCollection(KJob *job)
         KMime::Message::Ptr newPage = KMime::Message::Ptr(new KMime::Message());
 
         QString title;
-        if (d->mTitle.isEmpty()) {
+        if (mTitle.isEmpty()) {
             const QDateTime currentDateTime = QDateTime::currentDateTime();
             title = NoteShared::NoteSharedGlobalConfig::self()->defaultTitle();
             title.replace(QStringLiteral("%t"), QLocale().toString(currentDateTime.time()));
             title.replace(QStringLiteral("%d"), QLocale().toString(currentDateTime.date(), QLocale::ShortFormat));
             title.replace(QStringLiteral("%l"), QLocale().toString(currentDateTime.date(), QLocale::LongFormat));
         } else {
-            title = d->mTitle;
+            title = mTitle;
         }
         QByteArray encoding("utf-8");
 
         newPage->subject(true)->fromUnicodeString(title, encoding);
-        newPage->contentType(true)->setMimeType(d->mRichText ? "text/html" : "text/plain");
+        newPage->contentType(true)->setMimeType(mRichText ? "text/html" : "text/plain");
         newPage->contentType()->setCharset("utf-8");
         newPage->contentTransferEncoding(true)->setEncoding(KMime::Headers::CEquPr);
         newPage->date(true)->setDateTime(QDateTime::currentDateTime());
         newPage->from(true)->fromUnicodeString(QStringLiteral("knotes@kde4"), encoding);
         // Need a non-empty body part so that the serializer regards this as a valid message.
-        newPage->mainBodyPart()->fromUnicodeString(d->mText.isEmpty() ? QStringLiteral(" ") : d->mText);
+        newPage->mainBodyPart()->fromUnicodeString(mText.isEmpty() ? QStringLiteral(" ") : mText);
 
         newPage->assemble();
 
@@ -173,8 +168,8 @@ void CreateNewNoteJob::slotFetchCollection(KJob *job)
         eda->setIconName(QStringLiteral("text-plain"));
         newItem.addAttribute(eda);
 
-        auto job = new Akonadi::ItemCreateJob(newItem, col, this);
-        connect(job, &Akonadi::ItemCreateJob::result, this, &CreateNewNoteJob::slotNoteCreationFinished);
+        auto createJob = new Akonadi::ItemCreateJob(newItem, col, this);
+        connect(createJob, &Akonadi::ItemCreateJob::result, this, &CreateNewNoteJob::slotNoteCreationFinished);
     } else {
         deleteLater();
     }
@@ -186,7 +181,7 @@ void CreateNewNoteJob::slotNoteCreationFinished(KJob *job)
         qCWarning(NOTESHARED_LOG) << job->errorString();
         NoteShared::NoteSharedGlobalConfig::self()->setDefaultFolder(-1);
         NoteShared::NoteSharedGlobalConfig::self()->save();
-        KMessageBox::error(d->mWidget, i18n("Note was not created."), i18n("Create new note"));
+        KMessageBox::error(mWidget, i18n("Note was not created."), i18n("Create new note"));
     }
     deleteLater();
 }
