@@ -8,6 +8,7 @@
 #include <QWidget>
 
 #include "noteshared_export.h"
+
 class KJob;
 
 namespace NoteShared
@@ -38,7 +39,12 @@ private Q_SLOTS:
 
 private:
     void createFetchCollectionJob(bool useSettings);
-    CreateNewNoteJobPrivate *const d;
+
+private:
+    QString mTitle;
+    QString mText;
+    bool mRichText = false;
+    QWidget *const mWidget;
 };
 }
 
