@@ -3,8 +3,7 @@
    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#ifndef POP3_METATYPE_H
-#define POP3_METATYPE_H
+#pragma once
 
 #include <QList>
 
@@ -12,4 +11,3 @@
 
 Q_DECLARE_METATYPE(QList<int>)
 
-#endif
