@@ -6,12 +6,12 @@
 #pragma once
 
 #include "noteshared_export.h"
-#include <AkonadiCore/Item>
+#include <Akonadi/Item>
 #include <QListWidget>
 
+
 namespace NoteShared
 {
-class NoteListWidgetPrivate;
 class NOTESHARED_EXPORT NoteListWidget : public QListWidget
 {
     Q_OBJECT
@@ -32,7 +32,9 @@ public:
 private:
     void createItem(const Akonadi::Item &note);
     enum listViewData { AkonadiId = Qt::UserRole + 1 };
-    NoteListWidgetPrivate *const d;
+
+private:
+    Akonadi::Item::List mNotes;
 };
 }
 
