@@ -3,8 +3,7 @@
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
-#ifndef KNOTES_OPTIONS_H
-#define KNOTES_OPTIONS_H
+#pragma once
 
 #include <KLocalizedString>
 #include <QCommandLineParser>
@@ -14,4 +13,3 @@ static void knotesOptions(QCommandLineParser *parser)
     parser->addOption(QCommandLineOption(QStringLiteral("skip-note"), i18n("Suppress creation of a new note on a non-unique instance.")));
 }
 
-#endif // KNOTES_OPTIONS_H
