@@ -31,23 +31,18 @@
 #include "resources/localresourcecreator.h"
 #include "utils/knoteutils.h"
 
-#include <AkonadiCore/ChangeRecorder>
-#include <AkonadiCore/ItemDeleteJob>
-#include <AkonadiCore/ItemFetchJob>
-#include <AkonadiCore/ItemFetchScope>
-#include <AkonadiCore/Session>
+#include <Akonadi/ChangeRecorder>
+#include <Akonadi/ItemDeleteJob>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
+#include <akonadi/session.h>
 
-#include <AkonadiWidgets/ControlGui>
+#include <Akonadi/ControlGui>
 
 #include <KMime/KMimeMessage>
 
 #include <KActionCollection>
-#include <kdnssd_version.h>
-#if KDNSSD_VERSION >= QT_VERSION_CHECK(5, 84, 0)
 #include <KDNSSD/PublicService>
-#else
-#include <DNSSD/PublicService>
-#endif
 #include <KGlobalAccel>
 #include <KIconEffect>
 #include <KLocalizedString>
@@ -246,9 +241,9 @@ void KNotesApp::slotDeleteSelectedNotes()
     }
     dlg->setNotes(lst);
     if (dlg->exec()) {
-        const Akonadi::Item::List lst = dlg->selectedNotes();
-        if (!lst.isEmpty()) {
-            auto deleteJob = new Akonadi::ItemDeleteJob(lst, this);
+        const Akonadi::Item::List lstItem = dlg->selectedNotes();
+        if (!lstItem.isEmpty()) {
+            auto deleteJob = new Akonadi::ItemDeleteJob(lstItem, this);
             connect(deleteJob, &KJob::result, this, &KNotesApp::slotNoteDeleteFinished);
         }
     }
