@@ -8,7 +8,7 @@
 
 #pragma once
 
-#include <AkonadiCore/Item>
+#include <Akonadi/Item>
 
 #include <KXMLGUIClient>
 
