@@ -6,28 +6,21 @@
  SPDX-License-Identifier: GPL-2.0-or-later
 *******************************************************************/
 
-#include <config-knotes.h>
-#include <kcmutils_version.h>
-
+#include "knoteconfigdialog.h"
 #include "config/noteactionconfig.h"
 #include "config/notenetworkconfig.h"
-#include "knoteconfigdialog.h"
+#include "kcoreaddons_version.h"
 #include "knotesglobalconfig.h"
 #include "notesharedglobalconfig.h"
 #include "print/knoteprintselectthemecombobox.h"
+#include <config-knotes.h>
 
 #include <KAuthorized>
-#include <KLocalizedString>
 #include <KNS3/DownloadDialog>
-#include <KPluginLoader>
 #include <KPluginMetaData>
 
 #include <QCheckBox>
-#include <QLabel>
-#include <QLineEdit>
 #include <QPushButton>
-#include <QToolButton>
-#include <QVBoxLayout>
 #include <QWhatsThis>
 
 KNoteConfigDialog::KNoteConfigDialog(const QString &title, QWidget *parent)
@@ -38,13 +31,9 @@ KNoteConfigDialog::KNoteConfigDialog(const QString &title, QWidget *parent)
     button(QDialogButtonBox::Ok)->setDefault(true);
 
     setWindowTitle(title);
-    const QVector<KPluginMetaData> availablePlugins = KPluginLoader::findPlugins(QStringLiteral("pim/kcms/knotes"));
+    const QVector<KPluginMetaData> availablePlugins = KPluginMetaData::findPlugins(QStringLiteral("pim/kcms/knotes"));
     for (const KPluginMetaData &metaData : availablePlugins) {
-#if KCMUTILS_VERSION >= QT_VERSION_CHECK(5, 84, 0)
         addModule(metaData);
-#else
-        addModule(metaData.pluginId());
-#endif
     }
 
     connect(button(QDialogButtonBox::Ok), &QPushButton::clicked, this, &KNoteConfigDialog::slotOk);
