@@ -20,7 +20,7 @@ KNotesKeyDialog::KNotesKeyDialog(KActionCollection *globals, QWidget *parent)
     auto mainLayout = new QVBoxLayout(this);
     m_keyChooser = new KShortcutsEditor(globals, this);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::RestoreDefaults, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::RestoreDefaults, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -40,7 +40,7 @@ KNotesKeyDialog::~KNotesKeyDialog()
 
 void KNotesKeyDialog::readConfig()
 {
-    KConfigGroup grp(KSharedConfig::openConfig(), "KNotesKeyDialog");
+    KConfigGroup grp(KSharedConfig::openStateConfig(), "KNotesKeyDialog");
     const QSize size = grp.readEntry("Size", QSize(300, 200));
     if (size.isValid()) {
         resize(size);
@@ -49,7 +49,7 @@ void KNotesKeyDialog::readConfig()
 
 void KNotesKeyDialog::writeConfig()
 {
-    KConfigGroup grp(KSharedConfig::openConfig(), "KNotesKeyDialog");
+    KConfigGroup grp(KSharedConfig::openStateConfig(), "KNotesKeyDialog");
     grp.writeEntry("Size", size());
     grp.sync();
 }
