@@ -27,7 +27,7 @@ KNoteFindDialog::KNoteFindDialog(QWidget *parent)
 {
     setWindowTitle(i18nc("@title:window", "Search Notes"));
     auto mainLayout = new QVBoxLayout(this);
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &KNoteFindDialog::reject);
     setAttribute(Qt::WA_DeleteOnClose);
     mNoteFindWidget = new KNoteFindWidget(this);
@@ -49,14 +49,14 @@ void KNoteFindDialog::setExistingNotes(const QHash<Akonadi::Item::Id, Akonadi::I
 
 void KNoteFindDialog::writeConfig()
 {
-    KConfigGroup grp(KSharedConfig::openConfig(), "KNoteFindDialog");
+    KConfigGroup grp(KSharedConfig::openStateConfig(), "KNoteFindDialog");
     grp.writeEntry("Size", size());
     grp.sync();
 }
 
 void KNoteFindDialog::readConfig()
 {
-    KConfigGroup grp(KSharedConfig::openConfig(), "KNoteFindDialog");
+    KConfigGroup grp(KSharedConfig::openStateConfig(), "KNoteFindDialog");
     const QSize size = grp.readEntry("Size", QSize(600, 300));
     if (size.isValid()) {
         resize(size);
@@ -70,7 +70,7 @@ KNoteFindWidget::KNoteFindWidget(QWidget *parent)
     vbox->setContentsMargins(0, 0, 0, 0);
     auto hbox = new QHBoxLayout;
     vbox->addLayout(hbox);
-    QLabel *lab = new QLabel(i18nc("@label:textbox", "Search notes:"), this);
+    auto lab = new QLabel(i18nc("@label:textbox", "Search notes:"), this);
     hbox->addWidget(lab);
     mSearchLineEdit = new QLineEdit(this);
     mSearchLineEdit->setClearButtonEnabled(true);
