@@ -6,7 +6,7 @@
 #pragma once
 
 #include "knotes_export.h"
-#include <AkonadiCore/Item>
+#include <Akonadi/Item>
 #include <QDialog>
 class QPushButton;
 class QLineEdit;
@@ -48,7 +48,7 @@ class KNOTES_EXPORT KNoteFindDialog : public QDialog
     Q_OBJECT
 public:
     explicit KNoteFindDialog(QWidget *parent = nullptr);
-    ~KNoteFindDialog();
+    ~KNoteFindDialog() override;
     void setExistingNotes(const QHash<Akonadi::Item::Id, Akonadi::Item> &notes);
 
 Q_SIGNALS:
