@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef KNOTECONFIGMODULE_H
-#define KNOTECONFIGMODULE_H
+#pragma once
 
 #include <KCModule>
 class QLineEdit;
@@ -16,7 +15,7 @@ class KNoteDisplayConfig : public KCModule
 {
     Q_OBJECT
 public:
-    explicit KNoteDisplayConfig(QWidget *parent);
+    explicit KNoteDisplayConfig(QWidget *parent = nullptr, const QVariantList &args = QVariantList());
     /** Reimplemented from KCModule. */
     void load() override;
     void save() override;
@@ -26,7 +25,7 @@ class KNoteEditorConfig : public KCModule
 {
     Q_OBJECT
 public:
-    explicit KNoteEditorConfig(QWidget *parent);
+    explicit KNoteEditorConfig(QWidget *parent = nullptr, const QVariantList &args = QVariantList());
     /** Reimplemented from KCModule. */
     void load() override;
     void save() override;
@@ -36,7 +35,7 @@ class KNoteMiscConfig : public KCModule
 {
     Q_OBJECT
 public:
-    explicit KNoteMiscConfig(QWidget *parent);
+    explicit KNoteMiscConfig(QWidget *parent = nullptr, const QVariantList &args = QVariantList());
     /** Reimplemented from KCModule. */
     void load() override;
     void save() override;
@@ -52,7 +51,7 @@ class KNotePrintConfig : public KCModule
 {
     Q_OBJECT
 public:
-    explicit KNotePrintConfig(QWidget *parent);
+    explicit KNotePrintConfig(QWidget *parent = nullptr, const QVariantList &args = QVariantList());
     /** Reimplemented from KCModule. */
     void load() override;
     void save() override;
@@ -70,7 +69,7 @@ class KNoteCollectionConfig : public KCModule
 {
     Q_OBJECT
 public:
-    explicit KNoteCollectionConfig(QWidget *parent);
+    explicit KNoteCollectionConfig(QWidget *parent = nullptr, const QVariantList &args = QVariantList());
     /** Reimplemented from KCModule. */
     void load() override;
     void save() override;
@@ -79,4 +78,3 @@ private:
     KNoteCollectionConfigWidget *mCollectionConfigWidget = nullptr;
 };
 
-#endif // KNOTECONFIGMODULE_H
