@@ -3,8 +3,7 @@
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
-#ifndef KCMKNOTESSUMMARY_H
-#define KCMKNOTESSUMMARY_H
+#pragma once
 
 #include <KCModule>
 #include <KViewStateMaintainer>
@@ -23,7 +22,7 @@ class KCMKNotesSummary : public KCModule
     Q_OBJECT
 
 public:
-    explicit KCMKNotesSummary(QWidget *parent = nullptr);
+    explicit KCMKNotesSummary(QWidget *parent = nullptr, const QVariantList &args = QVariantList());
 
     void load() override;
     void save() override;
@@ -42,4 +41,3 @@ private:
     KViewStateMaintainer<Akonadi::ETMViewStateSaver> *mModelState = nullptr;
 };
 
-#endif
