@@ -36,25 +36,20 @@
 #include "resources/localresourcecreator.h"
 #include "utils/knoteutils.h"
 
-#include <AkonadiCore/ChangeRecorder>
-#include <AkonadiCore/ItemDeleteJob>
-#include <AkonadiCore/ItemFetchJob>
-#include <AkonadiCore/ItemFetchScope>
-#include <AkonadiCore/ItemModifyJob>
-#include <AkonadiCore/Session>
-#include <AkonadiWidgets/ControlGui>
-#include <AkonadiWidgets/ETMViewStateSaver>
+#include <Akonadi/ChangeRecorder>
+#include <Akonadi/ControlGui>
+#include <Akonadi/ETMViewStateSaver>
+#include <Akonadi/ItemDeleteJob>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
+#include <Akonadi/ItemModifyJob>
+#include <akonadi/session.h>
 
 #include <KMime/KMimeMessage>
 
 #include <KActionCollection>
 #include <KCheckableProxyModel>
-#include <kdnssd_version.h>
-#if KDNSSD_VERSION >= QT_VERSION_CHECK(5, 84, 0)
 #include <KDNSSD/PublicService>
-#else
-#include <DNSSD/PublicService>
-#endif
 #include <KLocalizedString>
 #include <KMessageBox>
 
@@ -422,16 +417,16 @@ void KNotesPart::killSelectedNotes()
     }
     QPointer<KNotesSelectDeleteNotesDialog> dlg = new KNotesSelectDeleteNotesDialog(items, widget());
     if (dlg->exec()) {
-        Akonadi::Item::List lst;
+        Akonadi::Item::List lstItem;
         QListIterator<KNotesIconViewItem *> kniviIt(items);
         while (kniviIt.hasNext()) {
             KNotesIconViewItem *iconViewIcon = kniviIt.next();
             if (!iconViewIcon->readOnly()) {
-                lst.append(iconViewIcon->item());
+                lstItem.append(iconViewIcon->item());
             }
         }
-        if (!lst.isEmpty()) {
-            auto job = new Akonadi::ItemDeleteJob(lst);
+        if (!lstItem.isEmpty()) {
+            auto job = new Akonadi::ItemDeleteJob(lstItem);
             connect(job, &Akonadi::ItemDeleteJob::result, this, &KNotesPart::slotDeleteNotesFinished);
         }
     }
