@@ -14,6 +14,7 @@
 #include <KCalUtils/ICalDrag>
 #include <KCalUtils/VCalDrag>
 #include <KCalendarCore/FileStorage>
+#include <KCalendarCore/MemoryCalendar>
 
 #include "knotes-version.h"
 
@@ -106,11 +107,10 @@ void KNotesPlugin::processDropEvent(QDropEvent *event)
         KContacts::Addressee::List::ConstIterator it;
 
         QStringList attendees;
-        KContacts::Addressee::List::ConstIterator end(contacts.constEnd());
-        for (it = contacts.constBegin(); it != end; ++it) {
-            const QString email = (*it).fullEmail();
+        for (const auto &contact : std::as_const(contacts)) {
+            const QString email = contact.fullEmail();
             if (email.isEmpty()) {
-                attendees.append((*it).realName() + QLatin1String("<>"));
+                attendees.append(contact.realName() + QLatin1String("<>"));
             } else {
                 attendees.append(email);
             }
