@@ -13,9 +13,9 @@
 #include "attributes/notedisplayattribute.h"
 #include "knotesinterface.h"
 
-#include <AkonadiCore/ChangeRecorder>
-#include <AkonadiCore/Session>
-#include <AkonadiWidgets/ETMViewStateSaver>
+#include <Akonadi/ChangeRecorder>
+#include <Akonadi/ETMViewStateSaver>
+#include <akonadi/session.h>
 
 #include <KontactInterface/Core>
 #include <KontactInterface/Plugin>
@@ -35,10 +35,9 @@
 
 KNotesSummaryWidget::KNotesSummaryWidget(KontactInterface::Plugin *plugin, QWidget *parent)
     : KontactInterface::Summary(parent)
+    , mDefaultPixmap(KIconLoader::global()->loadIcon(QStringLiteral("knotes"), KIconLoader::Desktop))
     , mPlugin(plugin)
-    , mInProgress(false)
 {
-    mDefaultPixmap = KIconLoader::global()->loadIcon(QStringLiteral("knotes"), KIconLoader::Desktop);
     auto mainLayout = new QVBoxLayout(this);
     mainLayout->setSpacing(3);
     mainLayout->setContentsMargins(3, 3, 3, 3);
