@@ -9,7 +9,7 @@
 
 #pragma once
 
-#include <AkonadiCore/Item>
+#include <Akonadi/Item>
 
 #include <KontactInterface/Summary>
 
