@@ -3,11 +3,11 @@
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
-#ifndef KNOTESMIGRATEAPPLICATION_H
-#define KNOTESMIGRATEAPPLICATION_H
-
+#pragma once
+#include <QObject>
+#include <kcoreaddons_version.h>
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include "knotes_export.h"
-
 #include <PimCommon/MigrateApplicationFiles>
 
 class KNOTES_EXPORT KNotesMigrateApplication
@@ -20,5 +20,4 @@ private:
     void initializeMigrator();
     PimCommon::MigrateApplicationFiles mMigrator;
 };
-
-#endif // KNOTESMIGRATEAPPLICATION_H
+#endif
