@@ -34,7 +34,7 @@ KNotePrintSelectedNotesDialog::KNotePrintSelectedNotesDialog(QWidget *parent)
     mButtonBox->addButton(mUser1Button, QDialogButtonBox::ActionRole);
     connect(mButtonBox, &QDialogButtonBox::accepted, this, &KNotePrintSelectedNotesDialog::accept);
     connect(mButtonBox, &QDialogButtonBox::rejected, this, &KNotePrintSelectedNotesDialog::reject);
-    QWidget *w = new QWidget;
+    auto w = new QWidget;
     auto vbox = new QVBoxLayout;
     vbox->setContentsMargins(0, 0, 0, 0);
     w->setLayout(vbox);
@@ -46,7 +46,7 @@ KNotePrintSelectedNotesDialog::KNotePrintSelectedNotesDialog(QWidget *parent)
     auto lay = new QHBoxLayout;
     lay->setContentsMargins(0, 0, 0, 0);
     vbox->addLayout(lay);
-    QLabel *lab = new QLabel(i18n("Printing theme:"));
+    auto lab = new QLabel(i18n("Printing theme:"));
     lay->addWidget(lab);
     mTheme = new KNotePrintSelectThemeComboBox;
     mTheme->loadThemes();
@@ -96,7 +96,7 @@ QList<KNotePrintObject *> KNotePrintSelectedNotesDialog::selectedNotes() const
     for (QListWidgetItem *item : lst) {
         Akonadi::Item::Id akonadiId = item->data(AkonadiId).toLongLong();
         if (akonadiId != -1) {
-            KNotePrintObject *obj = new KNotePrintObject(mNotes.value(akonadiId)->item());
+            auto obj = new KNotePrintObject(mNotes.value(akonadiId)->item());
             lstPrintObj.append(obj);
         }
     }
@@ -115,7 +115,7 @@ bool KNotePrintSelectedNotesDialog::preview() const
 
 void KNotePrintSelectedNotesDialog::readConfig()
 {
-    KConfigGroup grp(KSharedConfig::openConfig(), "KNotePrintSelectedNotesDialog");
+    KConfigGroup grp(KSharedConfig::openStateConfig(), "KNotePrintSelectedNotesDialog");
     const QSize size = grp.readEntry("Size", QSize(300, 200));
     if (size.isValid()) {
         resize(size);
@@ -124,7 +124,7 @@ void KNotePrintSelectedNotesDialog::readConfig()
 
 void KNotePrintSelectedNotesDialog::writeConfig()
 {
-    KConfigGroup grp(KSharedConfig::openConfig(), "KNotePrintSelectedNotesDialog");
+    KConfigGroup grp(KSharedConfig::openStateConfig(), "KNotePrintSelectedNotesDialog");
     grp.writeEntry("Size", size());
     grp.sync();
 }
